@@ -12,10 +12,14 @@ __version__ = version.__version__
 from rasa.run import run
 from rasa.train import train
 from rasa.test import test
+from rasa.constants import (
+    ENV_ENABLE_JSON_LOGGING,
+    ENV_LOG_LEVEL
+)
 
-if os.environ.get('ENABLE_JSON_LOGGING', False):
+if ENV_ENABLE_JSON_LOGGING:
     json_logging.init_non_web(enable_json=True)
-    LOG_LEVEL = os.environ.get('LOG_LEVEL', 'INFO')
+    LOG_LEVEL = ENV_LOG_LEVEL
     logging.basicConfig(level=LOG_LEVEL)
     json_logging.config_root_logger()
 
