@@ -728,7 +728,7 @@ class Agent:
         app.run(
             host="0.0.0.0",
             port=http_port,
-            backlog=int(os.environ.get(ENV_SANIC_BACKLOG, "100")),
+            backlog=ENV_SANIC_BACKLOG,
             workers=rasa.core.utils.number_of_sanic_workers(self.lock_store),
         )
 
