@@ -19,7 +19,7 @@ from typing import Text, List, Dict, Any, Optional, Callable, Iterable, Awaitabl
 
 import rasa.utils.endpoints
 from rasa.cli import utils as cli_utils
-from rasa.constants import DOCS_BASE_URL
+from rasa.constants import DOCS_BASE_URL, ENV_CHANNEL_ID, ENV_OMNI_API_URL
 from rasa.core import utils
 from sanic.response import HTTPResponse
 
@@ -29,8 +29,8 @@ except ImportError:
     from urllib.parse import urljoin
 
 logger = logging.getLogger(__name__)
-OMNI_API_URL = environ.get("OMNI_API_URL", "http://omni-api:80")
-CHANNEL_ID = environ.get("CHANNEL_ID", 3)
+OMNI_API_URL = ENV_OMNI_API_URL
+CHANNEL_ID = ENV_CHANNEL_ID
 
 class UserMessage:
     """Represents an incoming message.
