@@ -263,9 +263,7 @@ class UserUttered(Event):
                 return word
         if message:
             text_numeric = t2d.convert(message)
-            phrase_arr = re.sub('\d', '{REDACTED}', text_numeric).split()
-            res = ' '.join(list(map(normalize_redaction, phrase_arr)))
-            return res
+            return text_numeric
         else:
             return message
 
@@ -447,9 +445,17 @@ class BotUttered(Event):
 
     def as_dict(self):
         d = super().as_dict()
-        d.update({"text": self.text, "data": self.data, "metadata": self.metadata, "message_id": self.message_id})
+        privacy = self.get_privacy_mode()
+        d.update({"text": self.text, "data": self.data, "metadata": self.metadata, "message_id": self.message_id, "privacy_mode": privacy})
         return d
 
+    def get_privacy_mode(self):
+        privacy_mode = False
+        if self.data.get('custom') and self.data.get('custom').get('privacy_mode') == True:
+            privacy_mode = True
+        return privacy_mode
+
+
     @classmethod
     def _from_parameters(cls, parameters):
         try:
