@@ -63,11 +63,15 @@ from rasa.core.trackers import DialogueStateTracker, EventVerbosity
 from rasa.utils.endpoints import EndpointConfig
 from rasa.utils.timer import timeit
 from rasa.utils.redactor import Redactor
+from rasa.constants import (
+    ENV_MAX_NUMBER_OF_PREDICTIONS,
+    ENV_MAX_PARTIALS_PROCESSED
+)
 
 logger = logging.getLogger(__name__)
 
-MAX_NUMBER_OF_PREDICTIONS = int(os.environ.get("MAX_NUMBER_OF_PREDICTIONS", "10"))
-MAX_PARTIALS_PROCESSED = int(os.environ.get("MAX_PARTIALS_PROCESSED", 2))
+MAX_NUMBER_OF_PREDICTIONS = ENV_MAX_NUMBER_OF_PREDICTIONS
+MAX_PARTIALS_PROCESSED = ENV_MAX_PARTIALS_PROCESSED
 
 
 redactor = Redactor()
@@ -686,8 +690,8 @@ class MessageProcessor:
             
             try:
                 fc_auth = aiohttp.BasicAuth(CDR_ACCOUNT_ID, CDR_ACCOUNT_TOKEN)
-                endpoint = f"{CDR_ENDPOINT}/Accounts/{CDR_ACCOUNT_ID}/Calls/{CDR_ACCOUNT_TOKEN}/AppNavs"
-                async with session.post(endpoint, auth=fc_auth, data=payload, ssl=False) as response:
+                endpoint = f"{CDR_ENDPOINT}/Accounts/{CDR_ACCOUNT_ID}/Calls/{conversation_id}/AppNavs"
+                async with session.request(method='POST',url=endpoint,json=payload,verify_ssl=False,auth=fc_auth) as response:
                     logger.info('[{}] - cdr submission: {}'.format(conversation_id, response.status))
             except aiohttp.ClientConnectorError as e:
                 logger.debug('[{}] - cdr connection error: {}'.format(conversation_id, str(e)))
@@ -702,7 +706,7 @@ class MessageProcessor:
             if (message.text == '/disconnect'):
                 app_nav = {
                     'key': '{}_disconnect'.format(message._metadata['template_name']),
-                    'value:': 'disconnect'
+                    'value': 'disconnect'
                 }
                 logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                 asyncio.create_task(self.send_app_nav_async(sender_id, app_nav))
@@ -712,7 +716,7 @@ class MessageProcessor:
                 if message.metadata.get('reporting_error_type', None):
                     app_nav = {
                     'key': '{}_nlu_{}'.format(message._metadata['template_name'], message._metadata['reporting_error_type']),
-                    'value:': 'NO_NTENT'
+                    'value': 'NO_INTENT'
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                     asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
@@ -721,7 +725,16 @@ class MessageProcessor:
                 elif message.missed_intent and message.intent['confidence'] < message._metadata['nlu_threshold']:
                     app_nav = {
                     'key': '{}_nlu_no_match'.format(message._metadata['template_name']),
-                    'value:': 'NO_NTENT'
+                    'value': 'NO_INTENT'
+                    }
+                    logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
+                    asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
+                    APP_NAV.labels(message._metadata['template_name'], 'no_match').inc()
+                    
+                elif message.intent and message.intent['name'] == USER_INTENT_OUT_OF_SCOPE:
+                    app_nav = {
+                        'key': '{}_nlu_no_match'.format(message._metadata['template_name'] ),
+                        'value': 'NO_INTENT'
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                     asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
@@ -730,7 +743,7 @@ class MessageProcessor:
                 elif message.intent['confidence'] > message._metadata['nlu_threshold']:
                     app_nav = {
                     'key': '{}_nlu_match'.format(message._metadata['template_name'] ),
-                    'value:': message.intent
+                    'value': message.intent['name']
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                     asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
