@@ -17,7 +17,7 @@ import rasa.utils
 import rasa.utils.common
 import rasa.utils.io
 from rasa import model, server
-from rasa.constants import ENV_SANIC_BACKLOG, ENV_SANIC_WORKERS, DEFAULT_SANIC_WORKERS
+from rasa.constants import ENV_ENABLE_JSON_LOGGING, ENV_KEEP_ALIVE_TIMEOUT, ENV_SANIC_ACCESS_LOG, ENV_SANIC_BACKLOG, ENV_SANIC_DEBUG_MODE, ENV_SANIC_KEEP_ALIVE, ENV_SANIC_WORKERS, DEFAULT_SANIC_WORKERS
 from rasa.core import agent, channels, constants
 from rasa.core.agent import Agent
 from rasa.core.channels import console
@@ -223,21 +223,21 @@ def serve_application(
     app.register_listener(close_session, "before_server_stop")
 
     rasa.utils.common.update_sanic_log_level(log_file)
-    num_workers = int(os.environ.get(ENV_SANIC_WORKERS, DEFAULT_SANIC_WORKERS))
+    num_workers = int(ENV_SANIC_WORKERS or DEFAULT_SANIC_WORKERS)
     logger.info("Spawning {} Sanic workers....".format(num_workers))
     monitor(app).expose_endpoint()
-    if os.environ.get('ENABLE_JSON_LOGGING', False):
+    if ENV_ENABLE_JSON_LOGGING:
         json_logging.init_sanic(enable_json=True)
         json_logging.init_request_instrument(app)
-    app.config['KEEP_ALIVE_TIMEOUT'] = int(os.environ.get("KEEP_ALIVE_TIMEOUT", 5))
-    app.config['KEEP_ALIVE'] = os.environ.get("SANIC_KEEP_ALIVE", True) != "False"
+    app.config['KEEP_ALIVE_TIMEOUT'] = ENV_KEEP_ALIVE_TIMEOUT
+    app.config['KEEP_ALIVE'] = ENV_SANIC_KEEP_ALIVE
     app.run(
         host="0.0.0.0",
         port=port,
-        access_log=os.environ.get("SANIC_ACCESS_LOG", False),
-        debug=os.environ.get("SANIC_DEBUG_MODE", False),
+        access_log=ENV_SANIC_ACCESS_LOG,
+        debug=ENV_SANIC_DEBUG_MODE,
         ssl=ssl_context,
-        backlog=int(os.environ.get(ENV_SANIC_BACKLOG, "100")),
+        backlog=ENV_SANIC_BACKLOG,
         workers=rasa.core.utils.number_of_sanic_workers(
             endpoints.lock_store if endpoints else None
         ),
