@@ -23,7 +23,7 @@ from rediscluster import RedisCluster
 from sqlalchemy import select, func, text, Table, MetaData, VARCHAR, bindparam
 
 from metrics.constants import OUTGOING_REQUEST_LATENCY_SEC
-from rasa.constants import ENV_LOG_LEVEL
+from rasa.constants import ENV_AUTHENTICATION_STATE, ENV_DB_SCHEMA, ENV_LOG_LEVEL, ENV_REDIS_SOCKET_TIMEOUT, ENV_SKIP_FULL_COVERAGE_CHECK, ENV_SQL_MAX_OVERFLOW, ENV_SQL_POOL_SIZE, LOG_LEVEL
 from rasa.core.actions.action import ACTION_LISTEN_NAME
 from rasa.core.brokers.event_channel import EventChannel
 from rasa.core.constants import DEFAULT_FALLBACK_ACTION
@@ -268,7 +268,7 @@ class TrackerStore:
     def is_authenticate_state(self, tracker):
         curr_state = tracker.current_state()
         active_form = curr_state.get('active_form')
-        return active_form.get('name') == os.environ.get('AUTHENTICATION_STATE', 'authentication_form')
+        return active_form.get('name') == ENV_AUTHENTICATION_STATE
 
     def number_of_existing_events(self, sender_id: Text) -> int:
         """Return number of stored events for a given sender id."""
@@ -546,8 +546,8 @@ class RedisClusterTrackerStore(TrackerStore):
         self.max_connections = max_connections
         self.delay = 5
         self.max_retries = 3
-        self.socket_timeout = float(os.environ.get('REDIS_SOCKET_TIMEOUT', 2.0))
-        self.skip_full_coverage_check = bool(os.environ.get('SKIP_FULL_COVERAGE_CHECK', True))
+        self.socket_timeout = ENV_REDIS_SOCKET_TIMEOUT
+        self.skip_full_coverage_check = ENV_SKIP_FULL_COVERAGE_CHECK
         self.health_check_retries = 0
         self.red_cluster = RedisCluster(
             startup_nodes=self.startup_nodes,
@@ -820,7 +820,7 @@ class SQLTrackerStore(TrackerStore):
         data = Column(Text(None, convert_unicode='force'), nullable=False)
         table = Table(
             __tablename__,
-            MetaData(schema=os.environ.get('DB_SCHEMA', 'dbo')),
+            MetaData(schema=ENV_DB_SCHEMA),
             Column('id', Integer, primary_key=True),
             Column('sender_id', String(255, convert_unicode='force'), nullable=False, index=True),
             Column('type_name', String(255, convert_unicode='force'), nullable=False),
@@ -850,11 +850,11 @@ class SQLTrackerStore(TrackerStore):
         engine_url = self.get_db_url(
             dialect, host, port, db, username, password, login_db, query
         )
-        echo_query = os.environ.get(ENV_LOG_LEVEL) == "DEBUG"
+        echo_query = ENV_LOG_LEVEL == "DEBUG"
         logger.debug(
             "Attempting to connect to database via '{}'.".format(repr(engine_url))
         )
-        self.DB_SCHEMA = os.environ.get('DB_SCHEMA', 'dbo')
+        self.DB_SCHEMA = ENV_DB_SCHEMA
         self.event_time_range = 14400  # 4 hours
 
         # Database might take a while to come up
@@ -867,13 +867,13 @@ class SQLTrackerStore(TrackerStore):
                 if dialect == "postgresql":
                     self.engine = create_engine(
                         engine_url,
-                        pool_size=int(os.environ.get("SQL_POOL_SIZE", "50")),
-                        max_overflow=int(os.environ.get("SQL_MAX_OVERFLOW", "100")),
+                        pool_size=ENV_SQL_POOL_SIZE,
+                        max_overflow=ENV_SQL_MAX_OVERFLOW,
                     )
                 elif dialect == 'pymssql':
                     self.engine = create_engine(f'mssql+pymssql://{username}:{password}@{host}/{db}?charset=utf8',
-                                                pool_size=int(os.environ.get("SQL_POOL_SIZE", "50")),
-                                                max_overflow=int(os.environ.get("SQL_MAX_OVERFLOW", "100")),
+                                                pool_size=ENV_SQL_POOL_SIZE,
+                                                max_overflow=ENV_SQL_MAX_OVERFLOW,
                                                 echo=echo_query,
                                                 isolation_level='AUTOCOMMIT')
                     logger.info(
