@@ -1,9 +1,11 @@
 import logging
 import typing
 from typing import Any, Dict, Hashable, List, Optional, Set, Text, Tuple
+import warnings
 
 from rasa.nlu.config import RasaNLUModelConfig, override_defaults
 from rasa.nlu.training_data import TrainingData, Message
+from rasa.nlu.constants import MESSAGE_RESPONSE_ATTRIBUTE
 
 if typing.TYPE_CHECKING:
     from rasa.nlu.model import Metadata
@@ -81,6 +83,23 @@ def validate_arguments(
         provided_properties.update(component.provides)
 
 
+def validate_required_components_from_data(
+    pipeline: List["Component"], data: TrainingData
+):
+
+    response_selector_exists = False
+    for component in pipeline:
+        # check if a response selector is part of NLU pipeline
+        if MESSAGE_RESPONSE_ATTRIBUTE in component.provides:
+            response_selector_exists = True
+
+    if len(data.response_examples) and not response_selector_exists:
+        warnings.warn(
+            "Training data consists examples for training a response selector but "
+            "no response selector component specified inside NLU pipeline"
+        )
+
+
 class MissingArgumentError(ValueError):
     """Raised when a function is called and not all parameters can be
     filled from the context / config.
@@ -90,7 +109,7 @@ class MissingArgumentError(ValueError):
     """
 
     def __init__(self, message: Text) -> None:
-        super(MissingArgumentError, self).__init__(message)
+        super().__init__(message)
         self.message = message
 
     def __str__(self) -> Text:
@@ -109,7 +128,7 @@ class UnsupportedLanguageError(Exception):
         self.component = component
         self.language = language
 
-        super(UnsupportedLanguageError, self).__init__(component, language)
+        super().__init__(component, language)
 
     def __str__(self) -> Text:
         return "component {} does not support language {}".format(
@@ -127,7 +146,7 @@ class ComponentMetaclass(type):
         return cls.__name__
 
 
-class Component(object, metaclass=ComponentMetaclass):
+class Component(metaclass=ComponentMetaclass):
     """A component is a message processing unit in a pipeline.
 
     Components are collected sequentially in a pipeline. Each component
@@ -215,7 +234,7 @@ class Component(object, metaclass=ComponentMetaclass):
         model_dir: Optional[Text] = None,
         model_metadata: Optional["Metadata"] = None,
         cached_component: Optional["Component"] = None,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> "Component":
         """Load this component from file.
 
@@ -360,7 +379,7 @@ class Component(object, metaclass=ComponentMetaclass):
         return language in cls.language_list
 
 
-class ComponentBuilder(object):
+class ComponentBuilder:
     """Creates trainers and interpreters based on configurations.
 
     Caches components for reuse.
@@ -410,7 +429,7 @@ class ComponentBuilder(object):
         component_meta: Dict[Text, Any],
         model_dir: Text,
         model_metadata: "Metadata",
-        **context: Any
+        **context: Any,
     ) -> Component:
         """Tries to retrieve a component from the cache, else calls
         ``load`` to create a new component.
