@@ -36,6 +36,7 @@ from rasa.constants import (
     DEFAULT_MODELS_PATH,
     DEFAULT_DOMAIN_PATH,
     DOCS_BASE_URL,
+    ENV_READY_CHECK_OFF
 )
 from rasa.core.agent import load_agent, Agent
 from rasa.core.channels.channel import (
@@ -481,7 +482,7 @@ def create_app(
     async def ready(request: Request):
         """Check if the server is running and responds with the version."""
         try:
-            if os.environ.get('READY_CHECK_OFF', None):
+            if ENV_READY_CHECK_OFF:
                 return response.json({"status": "ok"})
             if endpoints.tracker_store:
                 resp = await app.agent.tracker_store.is_healthy()
