@@ -1,45 +1,51 @@
 import asyncio
 import errno
+import json
 import logging
 import os
 import tarfile
 import tempfile
+import typing
 import warnings
 import zipfile
 import glob
 from asyncio import AbstractEventLoop
-from typing import Text, Any, Dict, Union, List, Type, Callable
-import ruamel.yaml as yaml
 from io import BytesIO as IOReader
+from pathlib import Path
+from typing import Text, Any, Dict, Union, List, Type, Callable
 
-import simplejson
-import typing
+import ruamel.yaml as yaml
 
-from rasa.constants import ENV_LOG_LEVEL, DEFAULT_LOG_LEVEL
+
+from rasa.constants import ENV_ENABLE_JSON_LOGGING, ENV_LOG_LEVEL
 
 if typing.TYPE_CHECKING:
     from prompt_toolkit.validation import Validator
 
+DEFAULT_ENCODING = "utf-8"
+
 
 def configure_colored_logging(loglevel):
-    import coloredlogs
+    if not ENV_ENABLE_JSON_LOGGING:
+        import coloredlogs
+        loglevel = loglevel or ENV_LOG_LEVEL
 
-    loglevel = loglevel or os.environ.get(ENV_LOG_LEVEL, DEFAULT_LOG_LEVEL)
-
-    field_styles = coloredlogs.DEFAULT_FIELD_STYLES.copy()
-    field_styles["asctime"] = {}
-    level_styles = coloredlogs.DEFAULT_LEVEL_STYLES.copy()
-    level_styles["debug"] = {}
-    coloredlogs.install(
-        level=loglevel,
-        use_chroot=False,
-        fmt="%(asctime)s %(levelname)-8s %(name)s  - %(message)s",
-        level_styles=level_styles,
-        field_styles=field_styles,
-    )
+        field_styles = coloredlogs.DEFAULT_FIELD_STYLES.copy()
+        field_styles["asctime"] = {}
+        level_styles = coloredlogs.DEFAULT_LEVEL_STYLES.copy()
+        level_styles["debug"] = {}
+        coloredlogs.install(
+            level=loglevel,
+            use_chroot=False,
+            fmt="%(asctime)s %(levelname)-8s %(name)s  - %(message)s",
+            level_styles=level_styles,
+            field_styles=field_styles,
+        )
 
 
-def enable_async_loop_debugging(event_loop: AbstractEventLoop) -> AbstractEventLoop:
+def enable_async_loop_debugging(
+    event_loop: AbstractEventLoop, slow_callback_duration: float = 0.1
+) -> AbstractEventLoop:
     logging.info(
         "Enabling coroutine debugging. Loop id {}.".format(id(asyncio.get_event_loop()))
     )
@@ -49,7 +55,7 @@ def enable_async_loop_debugging(event_loop: AbstractEventLoop) -> AbstractEventL
 
     # Make the threshold for "slow" tasks very very small for
     # illustration. The default is 0.1 (= 100 milliseconds).
-    event_loop.slow_callback_duration = 0.001
+    event_loop.slow_callback_duration = slow_callback_duration
 
     # Report all mistakes managing asynchronous resources.
     warnings.simplefilter("always", ResourceWarning)
@@ -100,6 +106,7 @@ def read_yaml(content: Text) -> Union[List[Any], Dict[Text, Any]]:
         content: A text containing yaml content.
     """
     fix_yaml_loader()
+
     replace_environment_variables()
 
     yaml_parser = yaml.YAML(typ="safe")
@@ -123,21 +130,21 @@ def read_yaml(content: Text) -> Union[List[Any], Dict[Text, Any]]:
         return yaml_parser.load(content) or {}
 
 
-def read_file(filename: Text, encoding: Text = "utf-8") -> Any:
+def read_file(filename: Text, encoding: Text = DEFAULT_ENCODING) -> Any:
     """Read text from a file."""
 
     try:
         with open(filename, encoding=encoding) as f:
             return f.read()
     except FileNotFoundError:
-        raise ValueError("File '{}' does not exist.".format(filename))
+        raise ValueError(f"File '{filename}' does not exist.")
 
 
 def read_json_file(filename: Text) -> Any:
     """Read json from a file."""
     content = read_file(filename)
     try:
-        return simplejson.loads(content)
+        return json.loads(content)
     except ValueError as e:
         raise ValueError(
             "Failed to read json from '{}'. Error: "
@@ -145,13 +152,19 @@ def read_json_file(filename: Text) -> Any:
         )
 
 
+def dump_obj_as_json_to_file(filename: Text, obj: Any) -> None:
+    """Dump an object as a json string to a file."""
+
+    write_text_file(json.dumps(obj, indent=2), filename)
+
+
 def read_config_file(filename: Text) -> Dict[Text, Any]:
     """Parses a yaml configuration file. Content needs to be a dictionary
 
      Args:
         filename: The path to the file which should be read.
     """
-    content = read_yaml(read_file(filename, "utf-8"))
+    content = read_yaml(read_file(filename))
 
     if content is None:
         return {}
@@ -171,7 +184,7 @@ def read_yaml_file(filename: Text) -> Union[List[Any], Dict[Text, Any]]:
      Args:
         filename: The path to the file which should be read.
     """
-    return read_yaml(read_file(filename, "utf-8"))
+    return read_yaml(read_file(filename, DEFAULT_ENCODING))
 
 
 def unarchive(byte_array: bytes, directory: Text) -> Text:
@@ -191,15 +204,35 @@ def unarchive(byte_array: bytes, directory: Text) -> Text:
         return directory
 
 
-def write_yaml_file(data: Dict, filename: Text):
+def write_yaml_file(data: Dict, filename: Union[Text, Path]) -> None:
     """Writes a yaml file.
 
      Args:
         data: The data to write.
         filename: The path to the file which should be written.
     """
-    with open(filename, "w", encoding="utf-8") as outfile:
-        yaml.dump(data, outfile, default_flow_style=False)
+    with open(str(filename), "w", encoding=DEFAULT_ENCODING) as outfile:
+        yaml.dump(data, outfile, default_flow_style=False, allow_unicode=True)
+
+
+def write_text_file(
+    content: Text,
+    file_path: Union[Text, Path],
+    encoding: Text = DEFAULT_ENCODING,
+    append: bool = False,
+) -> None:
+    """Writes text to a file.
+
+    Args:
+        content: The content to write.
+        file_path: The path to which the content should be written.
+        encoding: The encoding which should be used.
+        append: Whether to append to the file or to truncate the file.
+
+    """
+    mode = "a" if append else "w"
+    with open(file_path, mode, encoding=encoding) as file:
+        file.write(content)
 
 
 def is_subdirectory(path: Text, potential_parent_directory: Text) -> bool:
@@ -217,7 +250,7 @@ def create_temporary_file(data: Any, suffix: Text = "", mode: Text = "w+") -> Te
 
     mode defines NamedTemporaryFile's  mode parameter in py3."""
 
-    encoding = None if "b" in mode else "utf-8"
+    encoding = None if "b" in mode else DEFAULT_ENCODING
     f = tempfile.NamedTemporaryFile(
         mode=mode, suffix=suffix, delete=False, encoding=encoding
     )
@@ -227,7 +260,7 @@ def create_temporary_file(data: Any, suffix: Text = "", mode: Text = "w+") -> Te
     return f.name
 
 
-def create_path(file_path: Text):
+def create_path(file_path: Text) -> None:
     """Makes sure all directories in the 'file_path' exists."""
 
     parent_dir = os.path.dirname(os.path.abspath(file_path))
@@ -238,12 +271,7 @@ def create_path(file_path: Text):
 def create_directory_for_file(file_path: Text) -> None:
     """Creates any missing parent directories of this file path."""
 
-    try:
-        os.makedirs(os.path.dirname(file_path))
-    except OSError as e:
-        # be happy if someone already created the path
-        if e.errno != errno.EEXIST:
-            raise
+    create_directory(os.path.dirname(file_path))
 
 
 def file_type_validator(
@@ -307,6 +335,11 @@ def list_subdirectories(path: Text) -> List[Text]:
     return [fn for fn in glob.glob(os.path.join(path, "*")) if os.path.isdir(fn)]
 
 
+def _filename_without_prefix(file: Text) -> Text:
+    """Splits of a filenames prefix until after the first ``_``."""
+    return "_".join(file.split("_")[1:])
+
+
 def list_directory(path: Text) -> List[Text]:
     """Returns all files and folders excluding hidden files.
 
@@ -324,9 +357,14 @@ def list_directory(path: Text) -> List[Text]:
     elif os.path.isdir(path):
         results = []
         for base, dirs, files in os.walk(path):
-            # remove hidden files
-            goodfiles = filter(lambda x: not x.startswith("."), files)
-            results.extend(os.path.join(base, f) for f in goodfiles)
+            # sort files for same order across runs
+            files = sorted(files, key=_filename_without_prefix)
+            # add not hidden files
+            good_files = filter(lambda x: not x.startswith("."), files)
+            results.extend(os.path.join(base, f) for f in good_files)
+            # add not hidden directories
+            good_directories = filter(lambda x: not x.startswith("."), dirs)
+            results.extend(os.path.join(base, f) for f in good_directories)
         return results
     else:
         raise ValueError(
@@ -355,5 +393,5 @@ def zip_folder(folder: Text) -> Text:
     zipped_path = tempfile.NamedTemporaryFile(delete=False)
     zipped_path.close()
 
-    # WARN: not thread save!
-    return shutil.make_archive(zipped_path.name, str("zip"), folder)
+    # WARN: not thread-safe!
+    return shutil.make_archive(zipped_path.name, "zip", folder)
