@@ -1,5 +1,30 @@
 import re
 from math import floor, log10
+from text2digits import text2digits
+import logging
+t2d = text2digits.Text2Digits()
+logger = logging.getLogger()  # get the root logger
+
+spanish_digit_set = {"cero", "uno", "dos", "tres", "quatro", "cinco", "seis", "siete", "ocho", "nueve"}
+
+spanish_to_english_digit_map = {"cero": "zero", "uno": "one", "dos": "two", "tres": "three", "quatro": "four",
+                                "cinco": "five", "seis": "six", "siete": "seven", "ocho": "eight", "nueve": "nine"}
+
+
+def spanish2english(message: str):
+    message_words = message.split()
+    if any(digit_string in message_words for digit_string in spanish_digit_set):
+        redacted_message = ''
+        for word in message_words:
+            if word.lower() in spanish_digit_set:
+                redacted_message += spanish_to_english_digit_map.get(word.lower()) + " "
+            else:
+                redacted_message += word + " "
+
+        redacted_message = redacted_message.rstrip().lstrip()
+        return redacted_message
+    else:
+        return message
 
 
 # Disclaimer: only tested up to ints of digit length of 20. sys.maxlength is 19 digits on a 64 bit processor.
@@ -25,16 +50,34 @@ class Redactor:
 
     # used for general case redaction
     def redact_string(self, message: str):
-        formatted_msg = re.sub("(?<=\\d) +(?=\\d)", "", message)
+        digit_msg = spanish2english(message)
+        try:
+            digit_msg = t2d.convert(digit_msg)
+        except Exception:
+            logger.info("text to digit conversion failed")
+
+        formatted_msg = re.sub("(?<=\\d) +(?=\\d)", "", digit_msg)
         return re.sub(r"(?<!\d)(\d{12,})(?!\d)", '****************', formatted_msg)
 
     # used when message is marked as pci
     def redact_string_strict(self, record: str):
-        formatted_msg = re.sub("(?<=\\d) +(?=\\d)", "", record)
+        digit_msg = spanish2english(record)
+        try:
+            digit_msg = t2d.convert(record)
+        except Exception:
+            logger.info("text to digit conversion failed")
+
+        formatted_msg = re.sub("(?<=\\d) +(?=\\d)", "", digit_msg)
         return re.sub(r"(?<!\d)(\d{3}|\d{4}|\d{6}|\d{12,})(?!\d)", '****************', formatted_msg)
 
     def redact_string_complete(self, message):
-        return self.redact_alphanum_sub(str(message))
+        digit_msg = spanish2english(message)
+        try:
+            digit_msg = t2d.convert(digit_msg)
+        except Exception:
+            logger.info("text to digit conversion failed")
+        formatted_msg = re.sub("(?<=\\d) +(?=\\d)", "", digit_msg)
+        return self.redact_alphanum_sub(str(digit_msg))
 
     def redact_int(self, number: int):
         """ Turns all integers with more than 11 digits into '*' strings of the same digit length """
@@ -201,7 +244,7 @@ class Redactor:
         for key in metadata.keys():
             if key == 'partials':
                 result[key] = self.redact_partials_list(metadata[key])
-            elif str(key) == 'original_text':
+            elif str(key) == 'original_text' or str(key) == 'no_match_input':
                 result[key] = self.redact_string_complete(metadata[key])
             else:
                 result[key] = self.redact_generic_strict(metadata[key])
@@ -237,4 +280,4 @@ class Redactor:
                     result[key] = event[key]
                 else:
                     result[key] = self.redact_generic(event[key])
-        return result
+        return result
\ No newline at end of file
