@@ -1,7 +1,13 @@
 import json
+from unittest.mock import patch
 
-from rasa.core import broker
-from rasa.core.broker import FileProducer, PikaProducer, KafkaProducer, SQLProducer
+from _pytest.monkeypatch import MonkeyPatch
+
+import rasa.core.brokers.utils as broker_utils
+from rasa.core.brokers.file_producer import FileProducer
+from rasa.core.brokers.kafka import KafkaProducer
+from rasa.core.brokers.pika import PikaProducer
+from rasa.core.brokers.sql import SQLProducer
 from rasa.core.events import Event, Restarted, SlotSet, UserUttered
 from rasa.utils.endpoints import EndpointConfig, read_endpoint_config
 from tests.core.conftest import DEFAULT_ENDPOINTS_FILE
@@ -17,18 +23,41 @@ def test_pika_broker_from_config():
     cfg = read_endpoint_config(
         "data/test_endpoints/event_brokers/pika_endpoint.yml", "event_broker"
     )
-    actual = broker.from_endpoint_config(cfg)
+    actual = broker_utils.from_endpoint_config(cfg)
 
     assert isinstance(actual, PikaProducer)
     assert actual.host == "localhost"
-    assert actual.credentials.username == "username"
+    assert actual.username == "username"
     assert actual.queue == "queue"
 
 
+# noinspection PyProtectedMember
+def test_pika_message_property_app_id(monkeypatch: MonkeyPatch):
+    # patch PikaProducer so it doesn't try to connect to RabbitMQ on init
+    import rasa.constants
+    import importlib
+    with patch.object(PikaProducer, "_run_pika", lambda _: None):
+        pika_producer = PikaProducer("", "", "")
+
+    # unset RASA_ENVIRONMENT env var results in empty App ID
+    monkeypatch.delenv("RASA_ENVIRONMENT", raising=False)
+    assert not pika_producer._message_properties.app_id
+
+    # setting it to some value results in that value as the App ID
+    rasa_environment = "some-test-environment"
+    monkeypatch.setenv("RASA_ENVIRONMENT", rasa_environment)
+    
+    # reload module and check value is updated
+    importlib.reload(rasa.constants)
+    importlib.reload(rasa.core.brokers.pika)
+
+    assert pika_producer._message_properties.app_id == rasa_environment
+
+
 def test_no_broker_in_config():
     cfg = read_endpoint_config(DEFAULT_ENDPOINTS_FILE, "event_broker")
 
-    actual = broker.from_endpoint_config(cfg)
+    actual = broker_utils.from_endpoint_config(cfg)
 
     assert actual is None
 
@@ -37,7 +66,7 @@ def test_sql_broker_from_config():
     cfg = read_endpoint_config(
         "data/test_endpoints/event_brokers/sql_endpoint.yml", "event_broker"
     )
-    actual = broker.from_endpoint_config(cfg)
+    actual = broker_utils.from_endpoint_config(cfg)
 
     assert isinstance(actual, SQLProducer)
     assert actual.engine.name == "sqlite"
@@ -47,15 +76,16 @@ def test_sql_broker_logs_to_sql_db():
     cfg = read_endpoint_config(
         "data/test_endpoints/event_brokers/sql_endpoint.yml", "event_broker"
     )
-    actual = broker.from_endpoint_config(cfg)
+    actual = broker_utils.from_endpoint_config(cfg)
 
     for e in TEST_EVENTS:
         actual.publish(e.as_dict())
 
-    events_types = [
-        json.loads(event.data)["event"]
-        for event in actual.session.query(actual.SQLBrokerEvent).all()
-    ]
+    with actual.session_scope() as session:
+        events_types = [
+            json.loads(event.data)["event"]
+            for event in session.query(actual.SQLBrokerEvent).all()
+        ]
 
     assert events_types == ["user", "slot", "restart"]
 
@@ -64,7 +94,7 @@ def test_file_broker_from_config():
     cfg = read_endpoint_config(
         "data/test_endpoints/event_brokers/file_endpoint.yml", "event_broker"
     )
-    actual = broker.from_endpoint_config(cfg)
+    actual = broker_utils.from_endpoint_config(cfg)
 
     assert isinstance(actual, FileProducer)
     assert actual.path == "rasa_event.log"
@@ -73,7 +103,7 @@ def test_file_broker_from_config():
 def test_file_broker_logs_to_file(tmpdir):
     fname = tmpdir.join("events.log").strpath
 
-    actual = broker.from_endpoint_config(
+    actual = broker_utils.from_endpoint_config(
         EndpointConfig(**{"type": "file", "path": fname})
     )
 
@@ -92,7 +122,7 @@ def test_file_broker_logs_to_file(tmpdir):
 def test_file_broker_properly_logs_newlines(tmpdir):
     fname = tmpdir.join("events.log").strpath
 
-    actual = broker.from_endpoint_config(
+    actual = broker_utils.from_endpoint_config(
         EndpointConfig(**{"type": "file", "path": fname})
     )
 
@@ -110,13 +140,13 @@ def test_file_broker_properly_logs_newlines(tmpdir):
 
 
 def test_load_custom_broker_name():
-    config = EndpointConfig(**{"type": "rasa.core.broker.FileProducer"})
-    assert broker.from_endpoint_config(config)
+    config = EndpointConfig(**{"type": "rasa.core.brokers.file_producer.FileProducer"})
+    assert broker_utils.from_endpoint_config(config)
 
 
 def test_load_non_existent_custom_broker_name():
-    config = EndpointConfig(**{"type": "rasa.core.broker.MyProducer"})
-    assert broker.from_endpoint_config(config) is None
+    config = EndpointConfig(**{"type": "rasa.core.brokers.my.MyProducer"})
+    assert broker_utils.from_endpoint_config(config) is None
 
 
 # Skip it for now since it requires a connection to a Kafka broker
