@@ -1,5 +1,9 @@
 import os
+from typing import Text
 
+from pathlib import Path
+
+import pytest
 from rasa.core.test import _generate_trackers, collect_story_predictions, test
 
 # we need this import to ignore the warning...
@@ -13,14 +17,14 @@ from tests.core.conftest import (
 )
 
 
-async def test_evaluation_image_creation(tmpdir, default_agent):
-    stories_path = os.path.join(tmpdir.strpath, "failed_stories.md")
-    img_path = os.path.join(tmpdir.strpath, "story_confmat.pdf")
+async def test_evaluation_image_creation(tmpdir: Path, default_agent: Agent):
+    stories_path = str(tmpdir / "failed_stories.md")
+    img_path = str(tmpdir / "story_confmat.pdf")
 
     await test(
         stories=DEFAULT_STORIES_FILE,
         agent=default_agent,
-        out_directory=tmpdir.strpath,
+        out_directory=str(tmpdir),
         max_stories=None,
         e2e=False,
     )
@@ -29,7 +33,7 @@ async def test_evaluation_image_creation(tmpdir, default_agent):
     assert os.path.isfile(stories_path)
 
 
-async def test_end_to_end_evaluation_script(tmpdir, restaurantbot):
+async def test_end_to_end_evaluation_script(restaurantbot: Text):
     restaurantbot = Agent.load(restaurantbot)
     completed_trackers = await _generate_trackers(
         END_TO_END_STORY_FILE, restaurantbot, use_e2e=True
@@ -62,6 +66,8 @@ async def test_end_to_end_evaluation_script(tmpdir, restaurantbot):
         "action_search_restaurants",
         "action_suggest",
         "action_listen",
+        "utter_ask_howcanhelp",
+        "action_listen",
         "greet",
         "greet",
         "inform",
@@ -71,6 +77,7 @@ async def test_end_to_end_evaluation_script(tmpdir, restaurantbot):
         "inform",
         "inform",
         "deny",
+        "greet",
         "[moderately](price:moderate)",
         "[east](location)",
         "[french](cuisine)",
@@ -84,10 +91,10 @@ async def test_end_to_end_evaluation_script(tmpdir, restaurantbot):
     assert story_evaluation.evaluation_store.serialise()[0] == serialised_store
     assert not story_evaluation.evaluation_store.has_prediction_target_mismatch()
     assert len(story_evaluation.failed_stories) == 0
-    assert num_stories == 3
+    assert num_stories == 4
 
 
-async def test_end_to_end_evaluation_script_unknown_entity(tmpdir, default_agent):
+async def test_end_to_end_evaluation_script_unknown_entity(default_agent: Agent):
     completed_trackers = await _generate_trackers(
         E2E_STORY_FILE_UNKNOWN_ENTITY, default_agent, use_e2e=True
     )
@@ -99,3 +106,16 @@ async def test_end_to_end_evaluation_script_unknown_entity(tmpdir, default_agent
     assert story_evaluation.evaluation_store.has_prediction_target_mismatch()
     assert len(story_evaluation.failed_stories) == 1
     assert num_stories == 1
+
+
+@pytest.mark.skip(reason="Broken test.")
+async def test_end_to_evaluation_with_forms(form_bot: Agent):
+    test_stories = await _generate_trackers(
+        "examples/formbot/tests/end-to-end-stories.md", form_bot, use_e2e=True
+    )
+
+    story_evaluation, num_stories = collect_story_predictions(
+        test_stories, form_bot, use_e2e=True
+    )
+
+    assert not story_evaluation.evaluation_store.has_prediction_target_mismatch()
