@@ -1,5 +1,6 @@
 import asyncio
 import uuid
+from typing import Text, Any
 
 import jsonschema
 import pytest
@@ -17,15 +18,6 @@ from rasa.core.agent import Agent
 from tests.core.conftest import DEFAULT_ENDPOINTS_FILE
 
 
-@pytest.fixture(scope="session")
-def loop():
-    loop = asyncio.new_event_loop()
-    asyncio.set_event_loop(loop)
-    loop = rasa.utils.io.enable_async_loop_debugging(loop)
-    yield loop
-    loop.close()
-
-
 def nlg_app(base_url="/"):
     app = Flask(__name__)
 
@@ -108,8 +100,8 @@ def test_nlg_schema_validation_empty_image():
         ("null", None),
     ],
 )
-def test_nlg_fill_template_text(slot_name, slot_value):
-    template = {"text": "{" + slot_name + "}"}
+def test_nlg_fill_template_text(slot_name: Text, slot_value: Any):
+    template = {"text": f"{{{slot_name}}}"}
     t = TemplatedNaturalLanguageGenerator(templates=dict())
     result = t._fill_template(template=template, filled_slots={slot_name: slot_value})
     assert result == {"text": str(slot_value)}
@@ -119,8 +111,8 @@ def test_nlg_fill_template_text(slot_name, slot_value):
     "img_slot_name, img_slot_value",
     [("url", "https://www.exampleimg.com"), ("img1", "https://www.appleimg.com")],
 )
-def test_nlg_fill_template_image(img_slot_name, img_slot_value):
-    template = {"image": "{" + img_slot_name + "}"}
+def test_nlg_fill_template_image(img_slot_name: Text, img_slot_value: Text):
+    template = {"image": f"{{{img_slot_name}}}"}
     t = TemplatedNaturalLanguageGenerator(templates=dict())
     result = t._fill_template(
         template=template, filled_slots={img_slot_name: img_slot_value}
@@ -147,20 +139,39 @@ def test_nlg_fill_template_image(img_slot_name, img_slot_value):
         ("null", None),
     ],
 )
-def test_nlg_fill_template_custom(slot_name, slot_value):
-    template = {"text": "{" + slot_name + "}"}
+def test_nlg_fill_template_custom(slot_name: Text, slot_value: Any):
     template = {
         "custom": {
-            "field": "{" + slot_name + "}",
-            "properties": {"field_prefixed": "prefix_{" + slot_name + "}"},
+            "field": f"{{{slot_name}}}",
+            "properties": {"field_prefixed": f"prefix_{{{slot_name}}}"},
         }
     }
     t = TemplatedNaturalLanguageGenerator(templates=dict())
     result = t._fill_template(template=template, filled_slots={slot_name: slot_value})
+
     assert result == {
         "custom": {
             "field": str(slot_value),
-            "properties": {"field_prefixed": "prefix_" + str(slot_value)},
+            "language": "English",
+            "properties": {"field_prefixed": f"prefix_{str(slot_value)}"},
+        }
+    }
+
+
+def test_nlg_fill_template_custom_with_list():
+    template = {
+        "custom": {
+            "blocks": [{"fields": [{"text": "*Departure date:*\n{test}"}]}],
+            "other": ["{test}"],
+        }
+    }
+    t = TemplatedNaturalLanguageGenerator(templates=dict())
+    result = t._fill_template(template=template, filled_slots={"test": 5})
+    assert result == {
+        "custom": {
+            "blocks": [{"fields": [{"text": "*Departure date:*\n5"}]}],
+            "language": "English",
+            "other": ["5"],
         }
     }
 
@@ -186,7 +197,7 @@ def test_nlg_fill_template_text_with_json(template_text, expected):
 
 @pytest.mark.parametrize("slot_name, slot_value", [("tag_w_\n", "a")])
 def test_nlg_fill_template_with_bad_slot_name(slot_name, slot_value):
-    template_text = "{" + slot_name + "}"
+    template_text = f"{{{slot_name}}}"
     t = TemplatedNaturalLanguageGenerator(templates=dict())
     result = t._fill_template(
         template={"text": template_text}, filled_slots={slot_name: slot_value}
@@ -204,7 +215,7 @@ def test_nlg_fill_template_with_bad_slot_name(slot_name, slot_value):
 def test_nlg_fill_template_image_and_text(
     text_slot_name, text_slot_value, img_slot_name, img_slot_value
 ):
-    template = {"text": "{" + text_slot_name + "}", "image": "{" + img_slot_name + "}"}
+    template = {"text": f"{{{text_slot_name}}}", "image": f"{{{img_slot_name}}}"}
     t = TemplatedNaturalLanguageGenerator(templates=dict())
     result = t._fill_template(
         template=template,
@@ -224,10 +235,10 @@ def test_nlg_fill_template_text_and_custom(
     text_slot_name, text_slot_value, cust_slot_name, cust_slot_value
 ):
     template = {
-        "text": "{" + text_slot_name + "}",
+        "text": f"{{{text_slot_name}}}",
         "custom": {
-            "field": "{" + cust_slot_name + "}",
-            "properties": {"field_prefixed": "prefix_{" + cust_slot_name + "}"},
+            "field": f"{{{cust_slot_name}}}",
+            "properties": {"field_prefixed": f"prefix_{{{cust_slot_name}}}"},
         },
     }
     t = TemplatedNaturalLanguageGenerator(templates=dict())
@@ -239,7 +250,8 @@ def test_nlg_fill_template_text_and_custom(
         "text": str(text_slot_value),
         "custom": {
             "field": str(cust_slot_value),
-            "properties": {"field_prefixed": "prefix_" + str(cust_slot_value)},
+            "language": "English",
+            "properties": {"field_prefixed": f"prefix_{str(cust_slot_value)}"},
         },
     }
 
@@ -260,7 +272,7 @@ def test_nlg_fill_template_attachment(attach_slot_name, attach_slot_value):
     "button_slot_name, button_slot_value", [("button_1", "button1")]
 )
 def test_nlg_fill_template_button(button_slot_name, button_slot_value):
-    template = {"button": "{" + button_slot_name + "}"}
+    template = {"button": f"{{{button_slot_name}}}"}
     t = TemplatedNaturalLanguageGenerator(templates=dict())
     result = t._fill_template(
         template=template, filled_slots={button_slot_name: button_slot_value}
@@ -274,7 +286,7 @@ def test_nlg_fill_template_button(button_slot_name, button_slot_value):
 def test_nlg_fill_template_quick_replies(
     quick_replies_slot_name, quick_replies_slot_value
 ):
-    template = {"quick_replies": "{" + quick_replies_slot_name + "}"}
+    template = {"quick_replies": f"{{{quick_replies_slot_name}}}"}
     t = TemplatedNaturalLanguageGenerator(templates=dict())
     result = t._fill_template(
         template=template,
